@@ -11,14 +11,15 @@
 
 class Read {
 public:
-    Read(const char* name, uint32_t name_length, const char* sequence,
-        uint32_t sequence_length)
+    Read(const char* name, std::uint32_t name_length,
+        const char* sequence, std::uint32_t sequence_length)
             : name_(name, name_length), sequence_(sequence, sequence_length),
             quality_() {
     }
 
-    Read(const char* name, uint32_t name_length, const char* sequence,
-        uint32_t sequence_length, const char* quality, uint32_t quality_length)
+    Read(const char* name, std::uint32_t name_length,
+        const char* sequence, std::uint32_t sequence_length,
+        const char* quality, std::uint32_t quality_length)
             : name_(name, name_length), sequence_(sequence, sequence_length),
             quality_(quality, quality_length) {
     }
@@ -30,8 +31,8 @@ public:
     std::string quality_;
 };
 
-void reads_summary(uint32_t& name_size, uint32_t& sequence_size, uint32_t& quality_size,
-    const std::vector<std::unique_ptr<Read>>& reads) {
+void reads_summary(std::uint32_t& name_size, std::uint32_t& sequence_size,
+    std::uint32_t& quality_size, const std::vector<std::unique_ptr<Read>>& reads) {
 
     name_size = 0;
     sequence_size = 0;
@@ -45,50 +46,87 @@ void reads_summary(uint32_t& name_size, uint32_t& sequence_size, uint32_t& quali
 
 class Overlap {
 public:
-    Overlap(uint64_t a_id, uint64_t b_id, double error, uint32_t minmers,
-        uint32_t a_rc, uint32_t a_begin, uint32_t a_end, uint32_t a_length,
-        uint32_t b_rc, uint32_t b_begin, uint32_t b_end, uint32_t b_length)
-            : q_name_(), q_id_(a_id - 1), q_begin_(a_begin), q_end_(a_end),
-            q_length_(a_length), t_name_(), t_id_(b_id - 1), t_begin_(b_begin),
-            t_end_(b_end), t_length_(b_length), orientation_(a_rc == b_rc ? '+' : '-'),
-            error_(error * 10000), minmers_(minmers), matching_bases_(), overlap_length_(),
+    Overlap(std::uint64_t a_id,
+        std::uint64_t b_id,
+        double error,
+        std::uint32_t minmers,
+        std::uint32_t a_rc,
+        std::uint32_t a_begin,
+        std::uint32_t a_end,
+        std::uint32_t a_length,
+        std::uint32_t b_rc,
+        std::uint32_t b_begin,
+        std::uint32_t b_end,
+        std::uint32_t b_length)
+            : q_name_(),
+            q_id_(a_id - 1),
+            q_begin_(a_begin),
+            q_end_(a_end),
+            q_length_(a_length),
+            t_name_(),
+            t_id_(b_id - 1),
+            t_begin_(b_begin),
+            t_end_(b_end),
+            t_length_(b_length),
+            orientation_(a_rc == b_rc ? '+' : '-'),
+            error_(error * 10000),
+            minmers_(minmers),
+            matching_bases_(),
+            overlap_length_(),
             mapping_quality_() {
     }
 
-    Overlap(const char* q_name, uint32_t q_name_length, uint32_t q_length,
-        uint32_t q_begin, uint32_t q_end, char orientation, const char* t_name,
-        uint32_t t_name_length, uint32_t t_length, uint32_t t_begin,
-        uint32_t t_end, uint32_t matching_bases, uint32_t overlap_length,
-        uint32_t quality)
-            : q_name_(q_name, q_name_length), q_id_(), q_begin_(q_begin),
-            q_end_(q_end), q_length_(q_length), t_name_(t_name, t_name_length),
-            t_id_(), t_begin_(t_begin), t_end_(t_end), t_length_(t_length),
-            orientation_(orientation), error_(), minmers_(),
-            matching_bases_(matching_bases), overlap_length_(overlap_length),
+    Overlap(const char* q_name, std::uint32_t q_name_length,
+        std::uint32_t q_length,
+        std::uint32_t q_begin,
+        std::uint32_t q_end,
+        char orientation,
+        const char* t_name, std::uint32_t t_name_length,
+        std::uint32_t t_length,
+        std::uint32_t t_begin,
+        std::uint32_t t_end,
+        std::uint32_t matching_bases,
+        std::uint32_t overlap_length,
+        std::uint32_t quality)
+            : q_name_(q_name, q_name_length),
+            q_id_(),
+            q_begin_(q_begin),
+            q_end_(q_end),
+            q_length_(q_length),
+            t_name_(t_name, t_name_length),
+            t_id_(),
+            t_begin_(t_begin),
+            t_end_(t_end),
+            t_length_(t_length),
+            orientation_(orientation),
+            error_(),
+            minmers_(),
+            matching_bases_(matching_bases),
+            overlap_length_(overlap_length),
             mapping_quality_(quality) {
     }
 
     ~Overlap() {}
 
     std::string q_name_;
-    uint64_t q_id_;
-    uint32_t q_begin_;
-    uint32_t q_end_;
-    uint32_t q_length_;
+    std::uint64_t q_id_;
+    std::uint32_t q_begin_;
+    std::uint32_t q_end_;
+    std::uint32_t q_length_;
     std::string t_name_;
-    uint64_t t_id_;
-    uint32_t t_begin_;
-    uint32_t t_end_;
-    uint32_t t_length_;
+    std::uint64_t t_id_;
+    std::uint32_t t_begin_;
+    std::uint32_t t_end_;
+    std::uint32_t t_length_;
     char orientation_;
-    uint32_t error_;
-    uint32_t minmers_;
-    uint32_t matching_bases_;
-    uint32_t overlap_length_;
-    uint32_t mapping_quality_;
+    std::uint32_t error_;
+    std::uint32_t minmers_;
+    std::uint32_t matching_bases_;
+    std::uint32_t overlap_length_;
+    std::uint32_t mapping_quality_;
 };
 
-void overlaps_summary(uint32_t& name_size, uint32_t& total_value,
+void overlaps_summary(std::uint32_t& name_size, std::uint32_t& total_value,
     const std::vector<std::unique_ptr<Overlap>>& overlaps) {
 
     name_size = 0;
@@ -115,35 +153,46 @@ void overlaps_summary(uint32_t& name_size, uint32_t& total_value,
 
 class Alignment {
 public:
-    Alignment(const char* q_name, uint32_t q_name_length, uint32_t flag,
-        const char* t_name, uint32_t t_name_length, uint32_t t_begin,
-        uint32_t mapping_quality, const char* cigar, uint32_t cigar_length,
-        const char* t_next_name, uint32_t t_next_name_length, uint32_t t_next_begin,
-        uint32_t template_length, const char* sequence, uint32_t sequence_length,
-        const char* quality, uint32_t quality_length)
-            : q_name_(q_name, q_name_length), flag_(flag), t_name_(t_name, t_name_length),
-            t_begin_(t_begin), mapping_quality_(mapping_quality),
-            cigar_(cigar, cigar_length), t_next_name_(t_next_name, t_next_name_length),
-            t_next_begin_(t_next_begin), template_length_(template_length),
-            sequence_(sequence, sequence_length), quality_(quality, quality_length) {
+    Alignment(const char* q_name, std::uint32_t q_name_length,
+        std::uint32_t flag,
+        const char* t_name, std::uint32_t t_name_length,
+        std::uint32_t t_begin,
+        std::uint32_t mapping_quality,
+        const char* cigar, std::uint32_t cigar_length,
+        const char* t_next_name, std::uint32_t t_next_name_length,
+        std::uint32_t t_next_begin,
+        std::uint32_t template_length,
+        const char* sequence, std::uint32_t sequence_length,
+        const char* quality, std::uint32_t quality_length)
+            : q_name_(q_name, q_name_length),
+            flag_(flag),
+            t_name_(t_name, t_name_length),
+            t_begin_(t_begin),
+            mapping_quality_(mapping_quality),
+            cigar_(cigar, cigar_length),
+            t_next_name_(t_next_name, t_next_name_length),
+            t_next_begin_(t_next_begin),
+            template_length_(template_length),
+            sequence_(sequence, sequence_length),
+            quality_(quality, quality_length) {
     }
 
     ~Alignment() {}
 
     std::string q_name_;
-    uint32_t flag_;
+    std::uint32_t flag_;
     std::string t_name_;
-    uint32_t t_begin_;
-    uint32_t mapping_quality_;
+    std::uint32_t t_begin_;
+    std::uint32_t mapping_quality_;
     std::string cigar_;
     std::string t_next_name_;
-    uint32_t t_next_begin_;
-    uint32_t template_length_;
+    std::uint32_t t_next_begin_;
+    std::uint32_t template_length_;
     std::string sequence_;
     std::string quality_;
 };
 
-void alignments_summary(uint32_t& string_size, uint32_t& total_value,
+void alignments_summary(std::uint32_t& string_size, std::uint32_t& total_value,
     const std::vector<std::unique_ptr<Alignment>>& alignments) {
 
     string_size = 0;
@@ -219,8 +268,12 @@ public:
 };
 
 TEST(BioparserTest, CreateParserError) {
-    EXPECT_DEATH((bioparser::createParser<bioparser::FastaParser, Read>("")),
-        ".bioparser::createParser. error: unable to open file !");
+    try {
+        auto parser = bioparser::createParser<bioparser::FastaParser, Read>("");
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::createParser] error: "
+            "unable to open file !");
+    }
 }
 
 TEST_F(BioparserFastaTest, ParseWhole) {
@@ -228,9 +281,9 @@ TEST_F(BioparserFastaTest, ParseWhole) {
     SetUp(bioparser_test_data_path + "sample.fasta");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(14U, reads.size());
@@ -239,14 +292,30 @@ TEST_F(BioparserFastaTest, ParseWhole) {
     EXPECT_EQ(0U, quality_size);
 }
 
+TEST_F(BioparserFastaTest, ParseWholeWithoutTrimming) {
+
+    SetUp(bioparser_test_data_path + "sample.fasta");
+
+    std::vector<std::unique_ptr<Read>> reads;
+    parser->parse(reads, -1, false);
+
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    reads_summary(name_size, sequence_size, quality_size, reads);
+
+    EXPECT_EQ(14U, reads.size());
+    EXPECT_EQ(75U, name_size);
+    EXPECT_EQ(109117U, sequence_size);
+    EXPECT_EQ(0U, quality_size);
+}
+
 TEST_F(BioparserFastaTest, CompressedParseWhole) {
 
     SetUp(bioparser_test_data_path + "sample.fasta.gz");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(14U, reads.size());
@@ -255,16 +324,32 @@ TEST_F(BioparserFastaTest, CompressedParseWhole) {
     EXPECT_EQ(0U, quality_size);
 }
 
+TEST_F(BioparserFastaTest, CompressedParseWholeWithoutTrimming) {
+
+    SetUp(bioparser_test_data_path + "sample.fasta.gz");
+
+    std::vector<std::unique_ptr<Read>> reads;
+    parser->parse(reads, -1, false);
+
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    reads_summary(name_size, sequence_size, quality_size, reads);
+
+    EXPECT_EQ(14U, reads.size());
+    EXPECT_EQ(75U, name_size);
+    EXPECT_EQ(109117U, sequence_size);
+    EXPECT_EQ(0U, quality_size);
+}
+
 TEST_F(BioparserFastaTest, ParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.fasta");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(14U, reads.size());
@@ -277,12 +362,12 @@ TEST_F(BioparserFastaTest, CompressedParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.fasta.gz");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(14U, reads.size());
@@ -296,8 +381,12 @@ TEST_F(BioparserFastaTest, FormatError) {
     SetUp(bioparser_test_data_path + "sample.fastq");
     std::vector<std::unique_ptr<Read>> reads;
 
-    EXPECT_DEATH(parser->parse_objects(reads, -1),
-        ".bioparser::FastaParser. error: invalid file format!");
+    try {
+        parser->parse(reads, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastaParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserFastaTest, CompressedFormatError) {
@@ -305,28 +394,42 @@ TEST_F(BioparserFastaTest, CompressedFormatError) {
     SetUp(bioparser_test_data_path + "sample.fastq.gz");
     std::vector<std::unique_ptr<Read>> reads;
 
-    EXPECT_DEATH(parser->parse_objects(reads, -1),
-        ".bioparser::FastaParser. error: invalid file format!");
+    try {
+        parser->parse(reads, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastaParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserFastaTest, ChunkSizeError) {
 
     SetUp(bioparser_test_data_path + "sample.fasta");
 
-    uint32_t size_in_bytes = 10 * 1024;
+    std::uint32_t size_in_bytes = 10 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    EXPECT_DEATH(parser->parse_objects(reads, size_in_bytes),
-        ".bioparser::FastaParser. error: too small chunk size!");
+
+    try {
+        parser->parse(reads, size_in_bytes);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastaParser] error: "
+            "too small chunk size!");
+    }
 }
 
 TEST_F(BioparserFastaTest, CompressedChunkSizeError) {
 
     SetUp(bioparser_test_data_path + "sample.fasta.gz");
 
-    uint32_t size_in_bytes = 10 * 1024;
+    std::uint32_t size_in_bytes = 10 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    EXPECT_DEATH(parser->parse_objects(reads, size_in_bytes),
-        ".bioparser::FastaParser. error: too small chunk size!");
+
+    try {
+        parser->parse(reads, size_in_bytes);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastaParser] error: "
+            "too small chunk size!");
+    }
 }
 
 TEST_F(BioparserFastaTest, ParseAndReset) {
@@ -334,19 +437,19 @@ TEST_F(BioparserFastaTest, ParseAndReset) {
     SetUp(bioparser_test_data_path + "sample.fasta");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t num_reads = reads.size(), name_size = 0, sequence_size = 0,
+    std::uint32_t num_reads = reads.size(), name_size = 0, sequence_size = 0,
         quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     reads.clear();
     parser->reset();
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t num_reads_new = reads.size(), name_size_new = 0,
+    std::uint32_t num_reads_new = reads.size(), name_size_new = 0,
         sequence_size_new = 0, quality_size_new = 0;
     reads_summary(name_size_new, sequence_size_new, quality_size_new, reads);
 
@@ -361,19 +464,19 @@ TEST_F(BioparserFastaTest, CompressedParseAndReset) {
     SetUp(bioparser_test_data_path + "sample.fasta.gz");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t num_reads = reads.size(), name_size = 0, sequence_size = 0,
+    std::uint32_t num_reads = reads.size(), name_size = 0, sequence_size = 0,
         quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     reads.clear();
     parser->reset();
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t num_reads_new = reads.size(), name_size_new = 0,
+    std::uint32_t num_reads_new = reads.size(), name_size_new = 0,
         sequence_size_new = 0, quality_size_new = 0;
     reads_summary(name_size_new, sequence_size_new, quality_size_new, reads);
 
@@ -388,9 +491,9 @@ TEST_F(BioparserFastqTest, ParseWhole) {
     SetUp(bioparser_test_data_path + "sample.fastq");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(13U, reads.size());
@@ -404,9 +507,9 @@ TEST_F(BioparserFastqTest, CompressedParseWhole) {
     SetUp(bioparser_test_data_path + "sample.fastq.gz");
 
     std::vector<std::unique_ptr<Read>> reads;
-    parser->parse_objects(reads, -1);
+    parser->parse(reads, -1);
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(13U, reads.size());
@@ -419,12 +522,12 @@ TEST_F(BioparserFastqTest, ParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.fastq");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(13U, reads.size());
@@ -437,12 +540,12 @@ TEST_F(BioparserFastqTest, CompressedParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.fastq.gz");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    while (parser->parse_objects(reads, size_in_bytes)) {
+    while (parser->parse(reads, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
+    std::uint32_t name_size = 0, sequence_size = 0, quality_size = 0;
     reads_summary(name_size, sequence_size, quality_size, reads);
 
     EXPECT_EQ(13U, reads.size());
@@ -457,8 +560,12 @@ TEST_F(BioparserFastqTest, FormatError) {
 
     std::vector<std::unique_ptr<Read>> reads;
 
-    EXPECT_DEATH(parser->parse_objects(reads, -1),
-        ".bioparser::FastqParser. error: invalid file format!");
+    try {
+        parser->parse(reads, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastqParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserFastqTest, CompressedFormatError) {
@@ -467,28 +574,42 @@ TEST_F(BioparserFastqTest, CompressedFormatError) {
 
     std::vector<std::unique_ptr<Read>> reads;
 
-    EXPECT_DEATH(parser->parse_objects(reads, -1),
-        ".bioparser::FastqParser. error: invalid file format!");
+    try {
+        parser->parse(reads, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastqParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserFastqTest, ChunkSizeError) {
 
     SetUp(bioparser_test_data_path + "sample.fastq");
 
-    uint32_t size_in_bytes = 10 * 1024;
+    std::uint32_t size_in_bytes = 10 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    EXPECT_DEATH(parser->parse_objects(reads, size_in_bytes),
-        ".bioparser::FastqParser. error: too small chunk size!");
+
+    try {
+        parser->parse(reads, size_in_bytes);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastqParser] error: "
+            "too small chunk size!");
+    }
 }
 
 TEST_F(BioparserFastqTest, CompressedChunkSizeError) {
 
     SetUp(bioparser_test_data_path + "sample.fastq.gz");
 
-    uint32_t size_in_bytes = 10 * 1024;
+    std::uint32_t size_in_bytes = 10 * 1024;
     std::vector<std::unique_ptr<Read>> reads;
-    EXPECT_DEATH(parser->parse_objects(reads, size_in_bytes),
-        ".bioparser::FastqParser. error: too small chunk size!");
+
+    try {
+        parser->parse(reads, size_in_bytes);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::FastqParser] error: "
+            "too small chunk size!");
+    }
 }
 
 TEST_F(BioparserMhapTest, ParseWhole) {
@@ -496,9 +617,9 @@ TEST_F(BioparserMhapTest, ParseWhole) {
     SetUp(bioparser_test_data_path + "sample.mhap");
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    parser->parse_objects(overlaps, -1);
+    parser->parse(overlaps, -1);
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(150U, overlaps.size());
@@ -511,9 +632,9 @@ TEST_F(BioparserMhapTest, CompressedParseWhole) {
     SetUp(bioparser_test_data_path + "sample.mhap.gz");
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    parser->parse_objects(overlaps, -1);
+    parser->parse(overlaps, -1);
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(150U, overlaps.size());
@@ -525,12 +646,12 @@ TEST_F(BioparserMhapTest, ParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.mhap");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    while (parser->parse_objects(overlaps, size_in_bytes)) {
+    while (parser->parse(overlaps, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(150U, overlaps.size());
@@ -542,12 +663,12 @@ TEST_F(BioparserMhapTest, CompressedParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.mhap.gz");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    while (parser->parse_objects(overlaps, size_in_bytes)) {
+    while (parser->parse(overlaps, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(150U, overlaps.size());
@@ -561,8 +682,12 @@ TEST_F(BioparserMhapTest, FormatError) {
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
 
-    EXPECT_DEATH(parser->parse_objects(overlaps, -1),
-        ".bioparser::MhapParser. error: invalid file format!");
+    try {
+        parser->parse(overlaps, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::MhapParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserMhapTest, CompressedFormatError) {
@@ -571,8 +696,12 @@ TEST_F(BioparserMhapTest, CompressedFormatError) {
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
 
-    EXPECT_DEATH(parser->parse_objects(overlaps, -1),
-        ".bioparser::MhapParser. error: invalid file format!");
+    try {
+        parser->parse(overlaps, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::MhapParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserPafTest, ParseWhole) {
@@ -580,9 +709,9 @@ TEST_F(BioparserPafTest, ParseWhole) {
     SetUp(bioparser_test_data_path + "sample.paf");
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    parser->parse_objects(overlaps, -1);
+    parser->parse(overlaps, -1);
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(500U, overlaps.size());
@@ -595,9 +724,9 @@ TEST_F(BioparserPafTest, CompressedParseWhole) {
     SetUp(bioparser_test_data_path + "sample.paf.gz");
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    parser->parse_objects(overlaps, -1);
+    parser->parse(overlaps, -1);
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(500U, overlaps.size());
@@ -609,12 +738,12 @@ TEST_F(BioparserPafTest, ParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.paf");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    while (parser->parse_objects(overlaps, size_in_bytes)) {
+    while (parser->parse(overlaps, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(500U, overlaps.size());
@@ -626,12 +755,12 @@ TEST_F(BioparserPafTest, CompressedParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.paf.gz");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Overlap>> overlaps;
-    while (parser->parse_objects(overlaps, size_in_bytes)) {
+    while (parser->parse(overlaps, size_in_bytes)) {
     }
 
-    uint32_t name_size = 0, total_value = 0;
+    std::uint32_t name_size = 0, total_value = 0;
     overlaps_summary(name_size, total_value, overlaps);
 
     EXPECT_EQ(500U, overlaps.size());
@@ -645,8 +774,12 @@ TEST_F(BioparserPafTest, FormatError) {
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
 
-    EXPECT_DEATH(parser->parse_objects(overlaps, -1),
-        ".bioparser::PafParser. error: invalid file format!");
+    try {
+        parser->parse(overlaps, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::PafParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserPafTest, CompressedFormatError) {
@@ -655,8 +788,12 @@ TEST_F(BioparserPafTest, CompressedFormatError) {
 
     std::vector<std::unique_ptr<Overlap>> overlaps;
 
-    EXPECT_DEATH(parser->parse_objects(overlaps, -1),
-        ".bioparser::PafParser. error: invalid file format!");
+    try {
+        parser->parse(overlaps, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::PafParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserSamTest, ParseWhole) {
@@ -664,9 +801,9 @@ TEST_F(BioparserSamTest, ParseWhole) {
     SetUp(bioparser_test_data_path + "sample.sam");
 
     std::vector<std::unique_ptr<Alignment>> alignments;
-    parser->parse_objects(alignments, -1);
+    parser->parse(alignments, -1);
 
-    uint32_t string_size = 0, total_value = 0;
+    std::uint32_t string_size = 0, total_value = 0;
     alignments_summary(string_size, total_value, alignments);
 
     EXPECT_EQ(48U, alignments.size());
@@ -679,9 +816,9 @@ TEST_F(BioparserSamTest, CompressedParseWhole) {
     SetUp(bioparser_test_data_path + "sample.sam.gz");
 
     std::vector<std::unique_ptr<Alignment>> alignments;
-    parser->parse_objects(alignments, -1);
+    parser->parse(alignments, -1);
 
-    uint32_t string_size = 0, total_value = 0;
+    std::uint32_t string_size = 0, total_value = 0;
     alignments_summary(string_size, total_value, alignments);
 
     EXPECT_EQ(48U, alignments.size());
@@ -693,12 +830,12 @@ TEST_F(BioparserSamTest, ParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.sam");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Alignment>> alignments;
-    while (parser->parse_objects(alignments, size_in_bytes)) {
+    while (parser->parse(alignments, size_in_bytes)) {
     }
 
-    uint32_t string_size = 0, total_value = 0;
+    std::uint32_t string_size = 0, total_value = 0;
     alignments_summary(string_size, total_value, alignments);
 
     EXPECT_EQ(48U, alignments.size());
@@ -710,12 +847,12 @@ TEST_F(BioparserSamTest, CompressedParseInChunks) {
 
     SetUp(bioparser_test_data_path + "sample.sam.gz");
 
-    uint32_t size_in_bytes = 64 * 1024;
+    std::uint32_t size_in_bytes = 64 * 1024;
     std::vector<std::unique_ptr<Alignment>> alignments;
-    while (parser->parse_objects(alignments, size_in_bytes)) {
+    while (parser->parse(alignments, size_in_bytes)) {
     }
 
-    uint32_t string_size = 0, total_value = 0;
+    std::uint32_t string_size = 0, total_value = 0;
     alignments_summary(string_size, total_value, alignments);
 
     EXPECT_EQ(48U, alignments.size());
@@ -729,8 +866,12 @@ TEST_F(BioparserSamTest, FormatError) {
 
     std::vector<std::unique_ptr<Alignment>> alignments;
 
-    EXPECT_DEATH(parser->parse_objects(alignments, -1),
-        ".bioparser::SamParser. error: invalid file format!");
+    try {
+        parser->parse(alignments, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::SamParser] error: "
+            "invalid file format!");
+    }
 }
 
 TEST_F(BioparserSamTest, CompressedFormatError) {
@@ -739,6 +880,10 @@ TEST_F(BioparserSamTest, CompressedFormatError) {
 
     std::vector<std::unique_ptr<Alignment>> alignments;
 
-    EXPECT_DEATH(parser->parse_objects(alignments, -1),
-        ".bioparser::SamParser. error: invalid file format!");
+    try {
+        parser->parse(alignments, -1);
+    } catch (std::invalid_argument& exception) {
+        EXPECT_STREQ(exception.what(), "[bioparser::SamParser] error: "
+            "invalid file format!");
+    }
 }
